MouseButton

Struct MouseButton 

#[repr(transparent)]
pub struct MouseButton { pub repr: u32, }
This enum type describes the different mouse buttons.

Fields

repr: u32

Implementations

Source

impl MouseButton

pub const NoButton: Self

The button state does not refer to any button.

pub const AllButtons: Self

This value corresponds to a mask of all possible mouse buttons. Use to set the ‘acceptedButtons’ property of a MouseArea to accept ALL mouse buttons.

pub const LeftButton: Self

The left button is pressed, or an event refers to the left button. (The left button may be the right button on left-handed mice.)

pub const RightButton: Self

The right button.

pub const MiddleButton: Self

The middle button.

pub const BackButton: Self

The ‘Back’ button. (Typically present on the ‘thumb’ side of a mouse with extra buttons. This is NOT the tilt wheel.)

pub const ForwardButton: Self

The ‘Forward’ button. (Typically present beside the ‘Back’ button, and also pressed by the thumb.)

pub const TaskButton: Self

The ‘Task’ button.

pub const ExtraButton4: Self

pub const ExtraButton5: Self

pub const ExtraButton6: Self

pub const ExtraButton7: Self

pub const ExtraButton8: Self

pub const ExtraButton9: Self

pub const ExtraButton10: Self

pub const ExtraButton11: Self

pub const ExtraButton12: Self

pub const ExtraButton13: Self

pub const ExtraButton14: Self

pub const ExtraButton15: Self

pub const ExtraButton16: Self

pub const ExtraButton17: Self

pub const ExtraButton18: Self

pub const ExtraButton19: Self

pub const ExtraButton20: Self

pub const ExtraButton21: Self

pub const ExtraButton22: Self

pub const ExtraButton23: Self

pub const ExtraButton24: Self