QByteArrayBase64Option

Struct QByteArrayBase64Option 

#[repr(transparent)]
pub struct QByteArrayBase64Option { pub repr: u32, }
This enum contains the options available for encoding and decoding Base64. Base64 is defined by RFC 4648.

An empty QFlags<QByteArrayBase64Option> will use the regular Base64 alphabet, called simply “base64”.

Fields

repr: u32

Implementations

Source

impl QByteArrayBase64Option

pub const Base64UrlEncoding: Self

An alternate alphabet, called “base64url”, which replaces two characters in the alphabet to be more friendly to URLs.

pub const OmitTrailingEquals: Self

Omits adding the padding equal signs at the end of the encoded data.