QGenericMatrix

Struct QGenericMatrix 

pub struct QGenericMatrix<const N: usize, const M: usize> { /* private fields */ }
The QGenericMatrix class is a template class that represents a NxM transformation matrix with N columns and M rows.

Note: CXX-Qt currently only supports QGenericMatrix of f32, while the C++ QGenericMatrix is generic over the contained type.

Qt Documentation: QGenericMatrix

Implementations

Source

impl<const N: usize, const M: usize> QGenericMatrix<N, M>

pub const fn new(values: &[[f32; N]; M]) -> Self

Available on crate feature qt_gui only.

Constructs a matrix from floating-point values in row-major order.

pub const fn data(&self) -> &[f32]

Available on crate feature qt_gui only.

Returns a reference to the raw data of this matrix.

pub fn data_mut(&mut self) -> &mut [f32]

Available on crate feature qt_gui only.

Returns a mutable reference to the raw data of this matrix.

pub fn copy_data_to(&self, values: &mut [f32])

Available on crate feature qt_gui only.

Retrieves the N * M items in this matrix and copies them to values in row-major order.

pub fn fill(&mut self, value: f32)

Available on crate feature qt_gui only.

Fills all elements of this matrix with value.

pub const fn filled(value: f32) -> Self

Available on crate feature qt_gui only.

Constructs a matrix with all values set to value.

pub const fn identity() -> Self

Available on crate feature qt_gui only.

Constructs a NxM identity matrix.

pub fn is_identity(&self) -> bool

Available on crate feature qt_gui only.

Returns true if this matrix is the identity; false otherwise.

pub const fn rows(&self) -> [[f32; N]; M]

Available on crate feature qt_gui only.

Constructs a two-dimensional array from the matrix in row-major order.

pub fn set_to_identity(&mut self)

Available on crate feature qt_gui only.

Sets this matrix to the identity.

pub const fn transposed(&self) -> QGenericMatrix<M, N>

Available on crate feature qt_gui only.

Returns this matrix, transposed about its diagonal.