QJsonArray

Struct QJsonArray 

pub struct QJsonArray { /* private fields */ }
The QJsonArray class encapsulates a JSON array.

Qt Documentation: QJsonArray

Implementations

Source

impl QJsonArray

pub fn append(&mut self, value: &QJsonValue)

Inserts value at the end of the array.

Source

impl QJsonArray

pub fn len(&self) -> isize

Returns the number of elements in the array.

pub fn is_empty(&self) -> bool

Returns true if the array is empty.

pub fn at(&self, i: isize) -> QJsonValue

Returns the element at position i. The returned QJsonValue is Undefined, if i is out of bounds.

pub fn iter(&self) -> Iter<'_>

Returns an iterator over the elements of the array.