QMessageLogContext

Struct QMessageLogContext 

pub struct QMessageLogContext<'a> { /* private fields */ }
The QMessageLogContext class defines the context passed to the Qt message handler.

Qt Documentation: QMessageLogContext

Implementations

Source

impl<'a> QMessageLogContext<'a>

pub fn new( file: &'a CStr, line: i32, function: &'a CStr, category: &'a CStr, ) -> QMessageLogContext<'a>

pub fn line(&self) -> i32

The line number given to the message handler.

pub fn file(&self) -> &'a CStr

The file path given to the message handler.

pub fn function(&self) -> &'a CStr

The name of the function given to the message handler.

pub fn category(&self) -> &'a CStr

The category given to the message handler.