QMetaTypeType

Struct QMetaTypeType 

#[repr(transparent)]
pub struct QMetaTypeType { pub repr: i32, }
Available on cxxqt_qt_version_major=6 only.
Types supported by QMetaType. This enum list is non-exhaustive, as additional types may be registered during runtime.

User-registered types should be greater than or equal to QMetaTypeType::User.

Fields

repr: i32

Implementations

Source

impl QMetaTypeType

pub const UnknownType: Self

This is an invalid type id. It is returned for types that are not registered.

pub const Bool: Self

pub const Int: Self

pub const UInt: Self

pub const LongLong: Self

pub const ULongLong: Self

pub const Double: Self

pub const Long: Self

pub const Short: Self

pub const Char: Self

pub const ULong: Self

pub const UShort: Self

pub const UChar: Self

pub const Float: Self

pub const VoidStar: Self

pub const QChar: Self

pub const QString: Self

pub const QStringList: Self

pub const QByteArray: Self

pub const QBitArray: Self

pub const QDate: Self

pub const QTime: Self

pub const QDateTime: Self

pub const QUrl: Self

pub const QLocale: Self

pub const QRect: Self

pub const QRectF: Self

pub const QSize: Self

pub const QSizeF: Self

pub const QLine: Self

pub const QLineF: Self

pub const QPoint: Self

pub const QPointF: Self

pub const QEasingCurve: Self

pub const QUuid: Self

pub const QVariant: Self

pub const QModelIndex: Self

pub const QPersistentModelIndex: Self

pub const QRegularExpression: Self

pub const QJsonValue: Self

pub const QJsonObject: Self

pub const QJsonArray: Self

pub const QJsonDocument: Self

pub const QByteArrayList: Self

pub const QObjectStar: Self

pub const SChar: Self

pub const Void: Self

pub const Nullptr: Self

pub const QVariantMap: Self

pub const QVariantList: Self

pub const QVariantHash: Self

pub const QCborSimpleType: Self

pub const QCborValue: Self

pub const QCborArray: Self

pub const QCborMap: Self

pub const Char16: Self

pub const Char32: Self

pub const QFont: Self

pub const QPixmap: Self

pub const QBrush: Self

pub const QColor: Self

pub const QPalette: Self

pub const QIcon: Self

pub const QImage: Self

pub const QPolygon: Self

pub const QRegion: Self

pub const QBitmap: Self

pub const QCursor: Self

pub const QKeySequence: Self

pub const QPen: Self

pub const QTextLength: Self

pub const QTextFormat: Self

pub const QTransform: Self

pub const QMatrix4x4: Self

pub const QVector2D: Self

pub const QVector3D: Self

pub const QVector4D: Self

pub const QQuaternion: Self

pub const QPolygonF: Self

pub const QColorSpace: Self

pub const QSizePolicy: Self

pub const User: Self