QQuickStyle

Struct QQuickStyle 

pub struct QQuickStyle { /* private fields */ }
The QQuickStyle class allows configuring the application style.

Qt Documentation: QQuickStyle

Implementations

Source

impl QQuickStyle

pub fn name() -> QString

Available on crate feature qt_quickcontrols only.

Returns the name of the application style.

Note: The application style can be specified by passing a -style command line argument. Therefore this function may not return a fully resolved value if called before constructing a QGuiApplication.

pub fn set_fallback_style(style: &QString)

Available on crate feature qt_quickcontrols only.

Sets the application fallback style to style.

Note: The fallback style must be the name of one of the built-in Qt Quick Controls styles, e.g. “Material”.

Note: The style must be configured before loading QML that imports Qt Quick Controls. It is not possible to change the style after the QML types have been registered.

The fallback style can be also specified by setting the QT_QUICK_CONTROLS_FALLBACK_STYLE environment variable.

pub fn set_style(style: &QString)

Available on crate feature qt_quickcontrols only.

Sets the application style to style.

Note: The style must be configured before loading QML that imports Qt Quick Controls. It is not possible to change the style after the QML types have been registered.