#[repr(transparent)]pub struct SplitBehaviorFlags {
pub repr: i32,
}Expand description
This enum specifies how QString::split functions should behave with respect to empty strings.
Fields
repr: i32Implementations
Sourceimpl SplitBehaviorFlags
impl SplitBehaviorFlags
Sourcepub const KeepEmptyParts: Self
pub const KeepEmptyParts: Self
If a field is empty, keep it in the result.
Sourcepub const SkipEmptyParts: Self
pub const SkipEmptyParts: Self
If a field is empty, don’t include it in the result.