#[repr(transparent)]pub struct MouseButton {
pub repr: u32,
}Expand description
This enum type describes the different mouse buttons.
Fields
repr: u32Implementations
Sourceimpl MouseButton
impl MouseButton
Sourcepub const AllButtons: Self
pub const AllButtons: Self
This value corresponds to a mask of all possible mouse buttons. Use to set the ‘acceptedButtons’ property of a MouseArea to accept ALL mouse buttons.
Sourcepub const LeftButton: Self
pub const LeftButton: Self
The left button is pressed, or an event refers to the left button. (The left button may be the right button on left-handed mice.)
Sourcepub const RightButton: Self
pub const RightButton: Self
The right button.
Sourcepub const MiddleButton: Self
pub const MiddleButton: Self
The middle button.
Sourcepub const BackButton: Self
pub const BackButton: Self
The ‘Back’ button. (Typically present on the ‘thumb’ side of a mouse with extra buttons. This is NOT the tilt wheel.)
Sourcepub const ForwardButton: Self
pub const ForwardButton: Self
The ‘Forward’ button. (Typically present beside the ‘Back’ button, and also pressed by the thumb.)
Sourcepub const TaskButton: Self
pub const TaskButton: Self
The ‘Task’ button.
pub const ExtraButton4: Self
pub const ExtraButton5: Self
pub const ExtraButton6: Self
pub const ExtraButton7: Self
pub const ExtraButton8: Self
pub const ExtraButton9: Self
pub const ExtraButton10: Self
pub const ExtraButton11: Self
pub const ExtraButton12: Self
pub const ExtraButton13: Self
pub const ExtraButton14: Self
pub const ExtraButton15: Self
pub const ExtraButton16: Self
pub const ExtraButton17: Self
pub const ExtraButton18: Self
pub const ExtraButton19: Self
pub const ExtraButton20: Self
pub const ExtraButton21: Self
pub const ExtraButton22: Self
pub const ExtraButton23: Self
pub const ExtraButton24: Self